==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/tabs/translations/tabs_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>@default</name>
    <message>
        <source>Tabs</source>
        <translation>Pestañas</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Accesos rápidos</translation>
    </message>
    <message>
        <source>Move tab left</source>
        <translation>Mover pestaña a la izquierda</translation>
    </message>
    <message>
        <source>Move tab right</source>
        <translation>Mover pestaña a la derecha</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Cambiar a la pestaña anterior</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Cambiar a la siguiente pestaña</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Conversación</translation>
    </message>
    <message>
        <source>Enable tabs in chat window</source>
        <translation>Habilitar las pestañas en la ventana de conversación</translation>
    </message>
    <message>
        <source>With this option, each chat will be opened in a separate tab in single window</source>
        <translation>Con esta opción, cada conversación se abrirá en una pestaña separada en una sola ventana</translation>
    </message>
    <message>
        <source>Closing window closes current tab only</source>
        <translation>Cerrar la ventana cierra sólo la actual pestaña</translation>
    </message>
    <message>
        <source>When enabled, closing chat window will cause closing only current tab, instead of all tabs and the window itself</source>
        <translation>Cuando esté habilitado, cerrar la ventana de conversación provocara solamente el cierre de la actual pestaña, en lugar de todas las pestañas y la propia ventana</translation>
    </message>
    <message>
        <source>Tab bar position</source>
        <translation>Posición de la barra de pestañas</translation>
    </message>
    <message>
        <source>Choose where you want the tab bar to be placed in chat window</source>
        <translation>Elija donde quiere colocar la barra de pestañas en la ventana de conversación</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation>Volver a abrir la pestaña cerrada</translation>
    </message>
    <message>
        <source>Show &apos;Open chat&apos; button</source>
        <translation>Mostrar botón de &apos;Abrir conversación&apos;</translation>
    </message>
    <message>
        <source>Show common &apos;Close Tab&apos; button on tab bar</source>
        <translation>Mostrar botón comun &apos;Cerrar Pestaña&apos; en la barrar de pestaña</translation>
    </message>
    <message>
        <source>Show &apos;Close&apos; button on each tab</source>
        <translation>Mostrar botón  de &apos;Cerrar&apos; en cada pestaña</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>New message received, close window anyway?</source>
        <translation>Nuevo mensaje recibido, ¿cerrar ventana de todos modos?</translation>
    </message>
    <message>
        <source>Recent Chats</source>
        <translation>Conversaciones recientes</translation>
    </message>
    <message>
        <source>Open Chat with...</source>
        <translation>Abrir conversación con...</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Pestañas</translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation>Cerrar pestaña</translation>
    </message>
    <message>
        <source>Close window</source>
        <translation>Cerrar ventana</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>TabsManager</name>
    <message>
        <source>Chat in New Window</source>
        <translation>Conversación en nueva ventana</translation>
    </message>
    <message>
        <source>Chat in New Tab</source>
        <translation>Conversación en nueva pestaña</translation>
    </message>
    <message>
        <source>Attach Chat to Tabs</source>
        <translation>Fijar la conversación a las pestañas</translation>
    </message>
    <message>
        <source>Detach</source>
        <translation>Separar</translation>
    </message>
    <message>
        <source>Detach all</source>
        <translation>Separar todos</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Close all</source>
        <translation>Cerrar todos</translation>
    </message>
    <message>
        <source>Close other tabs</source>
        <translation>Cerrar otras pestañas</translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation>Volver a abrir la pestaña cerrada</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/tabs/translations/tabs_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Tabs</source>
        <translation>Pestañas</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Accesos rápidos</translation>
    </message>
    <message>
        <source>Move tab left</source>
        <translation>Mover pestaña a la izquierda</translation>
    </message>
    <message>
        <source>Move tab right</source>
        <translation>Mover pestaña a la derecha</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Cambiar a la pestaña anterior</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Cambiar a la siguiente pestaña</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Conversación</translation>
    </message>
    <message>
        <source>Enable tabs in chat window</source>
        <translation>Habilitar las pestañas en la ventana de conversación</translation>
    </message>
    <message>
        <source>With this option, each chat will be opened in a separate tab in single window</source>
        <translation>Con esta opción, cada conversación se abrirá en una pestaña separada en una sola ventana</translation>
    </message>
    <message>
        <source>Closing window closes current tab only</source>
        <translation>Cerrar la ventana cierra sólo la actual pestaña</translation>
    </message>
    <message>
        <source>When enabled, closing chat window will cause closing only current tab, instead of all tabs and the window itself</source>
        <translation>Cuando esté habilitado, cerrar la ventana de conversación provocara solamente el cierre de la actual pestaña, en lugar de todas las pestañas y la propia ventana</translation>
    </message>
    <message>
        <source>Tab bar position</source>
        <translation>Posición de la barra de pestañas</translation>
    </message>
    <message>
        <source>Choose where you want the tab bar to be placed in chat window</source>
        <translation>Elija donde quiere colocar la barra de pestañas en la ventana de conversación</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation>Volver a abrir la pestaña cerrada</translation>
    </message>
    <message>
        <source>Show &apos;Open chat&apos; button</source>
        <translation>Mostrar botón de &apos;Abrir conversación&apos;</translation>
    </message>
    <message>
        <source>Show common &apos;Close Tab&apos; button on tab bar</source>
        <translation>Mostrar botón comun &apos;Cerrar Pestaña&apos; en la barrar de pestaña</translation>
    </message>
    <message>
        <source>Show &apos;Close&apos; button on each tab</source>
        <translation>Mostrar botón  de &apos;Cerrar&apos; en cada pestaña</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>New message received, close window anyway?</source>
        <translation>Nuevo mensaje recibido, ¿cerrar ventana de todos modos?</translation>
    </message>
    <message>
        <source>Recent Chats</source>
        <translation>Conversaciones recientes</translation>
    </message>
    <message>
        <source>Open Chat with...</source>
        <translation>Abrir conversación con...</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Pestañas</translation>
    </message>
    <message>
        <source>Close Tab</source>
        <translation>Cerrar pestaña</translation>
    </message>
    <message>
        <source>Close window</source>
        <translation>Cerrar ventana</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>TabsManager</name>
    <message>
        <source>Chat in New Window</source>
        <translation>Conversación en nueva ventana</translation>
    </message>
    <message>
        <source>Chat in New Tab</source>
        <translation>Conversación en nueva pestaña</translation>
    </message>
    <message>
        <source>Attach Chat to Tabs</source>
        <translation>Fijar la conversación a las pestañas</translation>
    </message>
    <message>
        <source>Detach</source>
        <translation>Separar</translation>
    </message>
    <message>
        <source>Detach all</source>
        <translation>Separar todos</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Close all</source>
        <translation>Cerrar todos</translation>
    </message>
    <message>
        <source>Close other tabs</source>
        <translation>Cerrar otras pestañas</translation>
    </message>
    <message>
        <source>Reopen closed tab</source>
        <translation>Volver a abrir la pestaña cerrada</translation>
    </message>
</context>
</TS>
